bidict
======
 
Efficient, Pythonic bidirectional map implementation and related functionality.

.. image:: https://raw.githubusercontent.com/jab/bidict/master/docs/_static/logo.png
    :target: https://bidict.readthedocs.org/
    :alt: bidict logo


Status
------

.. image:: https://img.shields.io/pypi/dm/bidict.svg
    :target: https://pypi.python.org/pypi/bidict
    :alt: Downloads per month

.. image:: https://img.shields.io/pypi/v/bidict.svg
    :target: https://pypi.python.org/pypi/bidict
    :alt: Latest release

.. image:: https://readthedocs.org/projects/bidict/badge/?version=latest
    :target: https://bidict.readthedocs.org/
    :alt: Documentation

.. image:: https://travis-ci.org/jab/bidict.svg?branch=master
    :target: https://travis-ci.org/jab/bidict
    :alt: Build status

.. image:: https://coveralls.io/repos/jab/bidict/badge.svg?branch=master
    :target: https://coveralls.io/r/jab/bidict
    :alt: Test coverage

.. image:: https://www.codacy.com/project/badge/1c5bfb83d2d54d57898d4ede1c9157ee
    :target: https://www.codacy.com/app/jab/bidict
    :alt: Code quality

.. image:: https://requires.io/github/jab/bidict/requirements.svg?branch=master
     :target: https://requires.io/github/jab/bidict/requirements/?branch=master
     :alt: Requirements Status

.. image:: https://img.shields.io/pypi/pyversions/bidict.svg
    :target: https://pypi.python.org/pypi/bidict
    :alt: Supported Python versions

.. image:: https://img.shields.io/pypi/implementation/bidict.svg
    :target: https://pypi.python.org/pypi/bidict
    :alt: Supported Python implementations

.. image:: https://img.shields.io/pypi/l/bidict.svg
    :target: https://raw.githubusercontent.com/jab/bidict/master/LICENSE
    :alt: License

.. image:: https://img.shields.io/badge/code%20of%20conduct-open-brightgreen.svg
    :target: http://todogroup.org/opencodeofconduct/#bidict/jab@math.brown.edu
    :alt: Code of Conduct

.. image:: https://badges.gitter.im/Join%20Chat.svg
    :target: https://gitter.im/jab/bidict
    :alt: Chat

Installation
------------

``pip install bidict``

Usage
-----

See https://bidict.readthedocs.org.

Participation
-------------

This project adheres to the
`Open Code of Conduct <http://todogroup.org/opencodeofconduct/#bidict/jab@math.brown.edu>`_.
By participating, you are expected to honor this code.

Please feel free to `create an issue <https://github.com/jab/bidict/issues/new>`_
or `join the chat room <https://gitter.im/jab/bidict>`_
if you have any questions, feedback, or just want to say hi or
talk about your use case.

bidict is the result of hundreds of hours of voluntary, unpaid work.
If bidict has helped you accomplish work you've been paid for,
please `support bidict <https://gumroad.com/l/bidict>`_
and/or ask your organization to do the same.
Your support directly contributes to bidict's sustainability.

.. image:: https://raw.githubusercontent.com/jab/bidict/master/docs/_static/support-on-gumroad.png
    :target: https://gumroad.com/l/bidict
    :alt: Support bidict

Check out
`CONTRIBUTING.rst <https://github.com/jab/bidict/blob/master/CONTRIBUTING.rst>`_
for more information about contributing.
